AGW Logo

svn SVN Revision 70555 For ultimatelistctrl

This file contains the SVN revision history for ultimatelistctrl, at revision 70555.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 07-Oct-2009 08:07:28 UTC
  • Committer: AG
  • File Size: 458458 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

  • GradientButton: applied patch from Werner and cleaned up a bit the useless parts of the code;
  • AuiToolBar/AuiDefaultDockArt: applied patch from Werner for default colour settings for AUI toolbars;
  • UltimateListCtrl: Fixed bug #13938. Also, don’t throw an error on key down if the list is empty.

svn_diff Diff To Previous Version (69824)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/ultimatelistctrl.py   2011/11/27 12:17:50     69824
+++ wxPython/3rdParty/AGW/agw/ultimatelistctrl.py   2012/02/09 20:52:26     70555
@@ -3,7 +3,7 @@
# Inspired by and heavily based on the wxWidgets C++ generic version of wxListCtrl.
#
# Andrea Gavana, @ 08 May 2009
# Latest Revision: 27 Nov 2011, 13.00 GMT
#
#
# TODO List
@@ -225,7 +225,7 @@

UltimateListCtrl is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 27 Nov 2011, 13.00 GMT
+Latest Revision: Andrea Gavana @ 09 Feb 2012, 21.00 GMT

Version 0.8

@@ -8054,7 +8054,11 @@
"""

parent = self.GetParent()
-
+
+        if self.IsVirtual() and self.GetItemCount() == 0:
+            event.Skip()
+            return
+
# we send a list_key event up
if self.HasCurrent():
le = UltimateListEvent(wxEVT_COMMAND_LIST_KEY_DOWN, self.GetParent().GetId())
@@ -12427,7 +12431,22 @@
return self._mainWin.PopupMenu(menu, pos)


-    def ClientToScreen(self, x, y):
+    def ClientToScreen(self, pointOrTuple):
+        """
+        Converts to screen coordinates from coordinates relative to this window.
+
+        :param `pointOrTuple`: an instance of `wx.Point` or a tuple representing the
+         `x`, `y` coordinates for this point.
+
+        :return: the coordinates relative to the screen.
+
+        :note: Overridden from `wx.PyControl`.
+        """
+
+        return self._mainWin.ClientToScreen(*pointOrTuple)
+
+
+    def ClientToScreenXY(self, x, y):
"""
Converts to screen coordinates from coordinates relative to this window.

@@ -12442,7 +12461,22 @@
return self._mainWin.ClientToScreen(x, y)


-    def ScreenToClient(self, x, y):
+    def ScreenToClient(self, pointOrTuple):
+        """
+        Converts from screen to client window coordinates.
+
+        :param `pointOrTuple`: an instance of `wx.Point` or a tuple representing the
+         `x`, `y` coordinates for this point.
+
+        :return: the coordinates relative to this window.
+
+        :note: Overridden from `wx.PyControl`.
+        """
+
+        return self._mainWin.ScreenToClient(*pointOrTuple)
+
+
+    def ScreenToClientXY(self, x, y):
"""
Converts from screen to client window coordinates.
Tree
@@ -3,7 +3,7 @@
#
# Andrea Gavana, @ 08 May 2009
-# Latest Revision: 27 Nov 2011, 13.00 GMT
+# Latest Revision: 09 Feb 2012, 21.00 GMT
#
#

Table Of Contents

Previous topic

SVN Revision 69824 For ultimatelistctrl

Next topic

xlsgrid